@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,17 +33,25 @@
 #ifndef YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED
 # define YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef INI_DEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define INI_DEBUG 1
+#  else
+#   define INI_DEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define INI_DEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined INI_DEBUG */
+#if INI_DEBUG
 extern int ini_debug;
 #endif
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef INI_TOKENTYPE
+# define INI_TOKENTYPE
+  enum ini_tokentype
   {
     END = 0,
     TC_SECTION = 258,
@@ -65,10 +73,10 @@ extern int ini_debug;
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef int YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+#if ! defined INI_STYPE && ! defined INI_STYPE_IS_DECLARED
+typedef zval INI_STYPE;
+# define INI_STYPE_IS_TRIVIAL 1
+# define INI_STYPE_IS_DECLARED 1
 #endif
 
 
